@@ -60,7 +60,7 @@ pub fn assert_booted() {
 #[macro_export]
 macro_rules! call_on_boot {
   ($boot_fn:block) => {
-    inventory::submit! {
+    booter::inventory::submit! {
       booter::BootBox {
         boot_fn: booter::atomic_take::AtomicTake::new(Box::new(|| $boot_fn))
       }
